Module std

Module std 

Structs

EndpointReceiver
Receiver part of synchronous channel. Must be used in cord context.
Sender
A sending-half of a channel. Can be used in OS thread context (because send may block tarantool or tokio runtime). Messages can be sent through this channel with Sender::send. Clone the sender if you need one more producer.

Functions

channel
Creates a new synchronous channel for communication with std threads, returning the sender/receiver halves.