Interfaces and components for internal usage.
Re-exports
pub use abi_stable;
Modules
- Migration
Context Validator_ trait - This module is generated by the
#[sabi_trait]attribute on MigrationContextValidator - Service
Stable_ trait - This module is generated by the
#[sabi_trait]attribute on ServiceStable - Validator_
trait - This module is generated by the
#[sabi_trait]attribute on Validator
Structs
- Migration
Context Validator_ TO - The trait object for MigrationContextValidator.
- Migration
Validator - A struct that holds all entities used for migration validation (currently, only the migration context validator)
- Pico
Context - Context of current instance. Produced by picodata.
- Service
Id - Unique service identifier.
- Service
Proxy - Implementation of
ServiceStable - Service
Registry - Registry for services. Used by picodata to create instances of services.
- Service
Stable_ TO - The trait object for ServiceStable.
- Validator_
TO - The trait object for Validator.
Traits
- Migration
Context Validator - Migration context validator stable trait.
- Service
- Service trait. Implement it in your code to create a service.
- Service
Stable - Safe trait for sending a service trait object between ABI boundary.
Define interface like
Servicetrait but using safe types fromabi_stablecrate. - Validator
- Config validator stable trait.
Type Aliases
- Callback
Result - Error
Box - Error type, return it from your callbacks.
- FnMigration
Validator - FnService
Registrar - Migration
Context Validator Box - Migration
Context Validator_ CTO - A type alias for the const-constructible
MigrationContextValidator_TO. - Service
Box - Final safe service trait object type. Can be used on both sides of ABI.
- Service
Stable_ CTO - A type alias for the const-constructible
ServiceStable_TO. - Validator
Box - Validator_
CTO - A type alias for the const-constructible
Validator_TO.