Module MigrationContextValidator_trait

Module MigrationContextValidator_trait 

This module is generated by the #[sabi_trait] attribute on MigrationContextValidator

Structs

MigrationContextValidator_Interface
A marker type describing the traits that are required when constructing MigrationContextValidator_TO,and are then implemented by it, by implementing the InterfaceType trait.
MigrationContextValidator_TO
The trait object for MigrationContextValidator.

Traits

MigrationContextValidator
Migration context validator stable trait.

Type Aliases

MigrationContextValidator_Backend
An alias for the underlying implementation of MigrationContextValidator_TO.
MigrationContextValidator_CTO
A type alias for the const-constructible MigrationContextValidator_TO.