Validator

Trait Validator 

pub trait Validator {
    // Required method
    fn validate(&self, config: RSlice<'_, u8>) -> RResult<(), ()>;
}
Config validator stable trait.

The reason for the existence of this trait is that abi_stable crate doesn’t support closures.

Required Methods

fn validate(&self, config: RSlice<'_, u8>) -> RResult<(), ()>

Validate plugin configuration.

Idempotency

WARNING This callback may be called several times in a row. It is the responsibility of the plugin author to make this function idempotent.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'lt, _ErasedPtr> Validator for Validator_TO<'lt, _ErasedPtr>
where Self:, _ErasedPtr: AsPtr<PtrTarget = ()>,