Module prelude

Module prelude 

Public picodata_plugin interface.

Re-exports

pub use crate::plugin::interface::CallbackResult;
pub use crate::plugin::interface::MigrationValidator;
pub use crate::plugin::interface::PicoContext;
pub use crate::plugin::interface::Service;
pub use crate::plugin::interface::ServiceRegistry;
pub use tarantool;

Attribute Macros

migration_validator
A procedural macro that lets you set up the migration validator. Right now, you can validate only the migration context, but using the set_context_validator for the whole context validation, and set_context_parameter_validator for per-parameter validation. For more information, check out these functions’ doc comments.
service_registrar