A channels for messaging between an OS thread (producer) and tarantool cord (consumer).
Structs
- Endpoint
Receiver - Receiver part of synchronous channel. Must be used in cord context.
- Sender
- A sending-half of a channel. Can be used in OS thread context (because
sendmay block tarantool or tokio runtime). Messages can be sent through this channel withSender::send. Clone the sender if you need one more producer.
Functions
- channel
- Creates a new synchronous channel, returning the sender/receiver halves. Please note that the receiver should only be used inside the cord.