Module interface

Module interface 

Interfaces and components for internal usage.

Re-exports

pub use abi_stable;

Modules

MigrationContextValidator_trait
This module is generated by the #[sabi_trait] attribute on MigrationContextValidator
ServiceStable_trait
This module is generated by the #[sabi_trait] attribute on ServiceStable
Validator_trait
This module is generated by the #[sabi_trait] attribute on Validator

Structs

MigrationContextValidator_TO
The trait object for MigrationContextValidator.
MigrationValidator
A struct that holds all entities used for migration validation (currently, only the migration context validator)
PicoContext
Context of current instance. Produced by picodata.
ServiceId
Unique service identifier.
ServiceProxy
Implementation of ServiceStable
ServiceRegistry
Registry for services. Used by picodata to create instances of services.
ServiceStable_TO
The trait object for ServiceStable.
Validator_TO
The trait object for Validator.

Traits

MigrationContextValidator
Migration context validator stable trait.
Service
Service trait. Implement it in your code to create a service.
ServiceStable
Safe trait for sending a service trait object between ABI boundary. Define interface like Service trait but using safe types from abi_stable crate.
Validator
Config validator stable trait.

Type Aliases

CallbackResult
ErrorBox
Error type, return it from your callbacks.
FnMigrationValidator
FnServiceRegistrar
MigrationContextValidatorBox
MigrationContextValidator_CTO
A type alias for the const-constructible MigrationContextValidator_TO.
ServiceBox
Final safe service trait object type. Can be used on both sides of ABI.
ServiceStable_CTO
A type alias for the const-constructible ServiceStable_TO.
ValidatorBox
Validator_CTO
A type alias for the const-constructible Validator_TO.