Public picodata_plugin interface.
Re-exports
pub use crate::plugin::interface::CallbackResult;pub use crate::plugin::interface::MigrationValidator;pub use crate::plugin::interface::PicoContext;pub use crate::plugin::interface::Service;pub use crate::plugin::interface::ServiceRegistry;pub use tarantool;
Attribute Macros
- migration_
validator - A procedural macro that lets you set up the migration validator. Right now, you
can validate only the migration context, but using the
set_context_validatorfor the whole context validation, andset_context_parameter_validatorfor per-parameter validation. For more information, check out these functions’ doc comments. - service_
registrar